import { __awaiter } from "tslib";
import fetch from "node-fetch";
import { handleCatchError } from "../helpers";
export function performConnectionConfigAuthorisation(instance) {
    return __awaiter(this, void 0, void 0, function* () {
        const configs = instance.configVariables.nodes;
        if (configs === null) {
            return {
                success: true,
                connectionsMade: [],
            };
        }
        const connectionConfigs = configs.filter(isPendingConnectionConfigWithAuthUrl);
        const connectionAuthAttemptPromises = connectionConfigs.map(attemptConnection);
        return Promise.all(connectionAuthAttemptPromises).then(formatConnectionResult);
    });
}
function attemptConnection(pendingConfig) {
    return __awaiter(this, void 0, void 0, function* () {
        const { authorizeUrl, requiredConfigVariable: { key, id }, } = pendingConfig;
        let result;
        try {
            const response = yield fetch(authorizeUrl, {
                redirect: "follow",
            });
            if ((response === null || response === void 0 ? void 0 : response.status) >= 200 && (response === null || response === void 0 ? void 0 : response.status) < 300) {
                result = {
                    success: true,
                };
            }
            else {
                result = {
                    success: false,
                    error: new Error(`Server response was not ok ${response === null || response === void 0 ? void 0 : response.status}`),
                };
            }
        }
        catch (err) {
            result = {
                success: false,
                error: handleCatchError(err),
            };
        }
        return {
            success: result.success,
            name: key,
            id: id,
            error: result.error,
        };
    });
}
function formatConnectionResult(results) {
    return results.some(({ success }) => !success)
        ? {
            success: false,
            error: new Error("One or more connections failed"),
            connectionsMade: results,
        }
        : { success: true, connectionsMade: results };
}
function isPendingConnectionConfigWithAuthUrl(value) {
    return (value !== null &&
        value.requiredConfigVariable.dataType === "CONNECTION" &&
        value.status === "PENDING" &&
        !!value.authorizeUrl);
}
